@@ -1,5 +1,5 @@
 setConstructorS3("AromaCore", function(pkgName="aroma.core", ...) {
-  extend(AromaPackage(pkgName), "AromaCore");
+  extend(AromaPackage(pkgName), "AromaCore")
 })
 
 
@@ -16,23 +16,14 @@ setMethodS3("fixSearchPath", "AromaCore", function(this, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Figure out which of our packages (aroma.core, aroma.light etc.) is
   # last on the search path.
-  aheadPkgs <- c("aroma.core", "aroma.light");
+  aheadPkgs <- c("aroma.core", "aroma.light")
 
   # Problematic package that must be after this package on the search path
-  behindPkgs <- c("grid", "affy");
+  behindPkgs <- c("grid", "affy")
 
   res <- fixSearchPathInternal(this, aheadPkgs=aheadPkgs,
-                                           behindPkgs=behindPkgs, ...);
+                                           behindPkgs=behindPkgs, ...)
 
   # Return the package actually moved
-  invisible(res);
+  invisible(res)
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2009-05-13
-# o Now extending the AromaPackage class.
-# o Created from 999.AromaAffymetrix.R.
-############################################################################
